@@ -39,6 +39,10 @@ async def _prepare_dead_letter_queue(channel: Channel,
                                      dl_exchange_type: str,
                                      default_queue_params: dict,
                                      bindings: Optional[list] = []) -> Queue:
+    if "x-dead-letter-exchange" in default_queue_params["arguments"].keys():
+        logger.warning("DL queue parameters can't contain x-dead-letter-exchange field!",
+                       extra={"full_message": "DL queue params: %s" % default_queue_params})
+        d = default_queue_params["arguments"].pop("x-dead-letter-exchange")
     dead_letter_queue: Queue = await channel.declare_queue(
         dl_queue_name,
         **default_queue_params
